#

##

##

##

###

###

    	later
    		# itinerary
    		# agenda

    	ranked

    		[ ] womb on
    			[ ] monetary on
    			[ ] sanique on

    		[ ] https://github.com/bohea/sanic-limiter

    		[ ] add a point to the map
    			[ ] store the point in mongo

    				DB:mesmerizing
    					collection:places [{
    						"name": [],
    						"notes": [],
    						"place": [{
    							"latitude": "",
    							"longitude": ""
    						}]
    					}]

    		[ ] add a region to the map
    			https://leafletjs.com/reference.html#polygon

    			[ ] store the region in mongo

    				DB:mesmerizing
    					collection:places [{
    						"name": [],
    						"notes": [],
    						"place": [{
    							"latitude": "",
    							"longitude": ""
    						},{
    							"latitude": "",
    							"longitude": ""
    						},{
    							"latitude": "",
    							"longitude": ""
    						}]
    					}]

    		[ ] https://www.openstreetmap.org/#map=5/38.007/-95.844

    	possibilities
    		[ ] retrieve the rectangular coordinates of the panel
    			[ ] add points and regions from your database
    				based on the math.

    		[ ] physics (climate) rhythms and guesses

    	possibilities
    		maps
    			https://www.openstreetmap.org/#map=5/38.007/-95.844
    				https://wiki.openstreetmap.org/wiki/API_v0.6

    			Leftlet:
    				https://leafletjs.com/

    			HERE

    			Mapquest

    			Google Maps

    			Bing Maps

    		places

    			Yelp